@@ -1,11 +1,12 @@
 """Basic summary statistics."""
 
-import numpy as np
-from typing import Callable, Dict, List, Union
 from abc import ABC, abstractmethod
+from typing import Callable, Dict, List, Tuple, Union
+
+import numpy as np
 
 from ..population import Sample
-from ..util import io_dict2arr, dict2arrlabels
+from ..util import dict2arrlabels, io_dict2arr
 
 
 class Sumstat(ABC):
@@ -78,7 +79,8 @@ class Sumstat(ABC):
         # initialize previous statistics
         if self.pre is not None:
             self.pre.initialize(
-                t=t, get_sample=get_sample, x_0=x_0, total_sims=total_sims)
+                t=t, get_sample=get_sample, x_0=x_0, total_sims=total_sims
+            )
 
     def update(
         self,
@@ -109,7 +111,8 @@ class Sumstat(ABC):
         """
         if self.pre is not None:
             return self.pre.update(
-                t=t, get_sample=get_sample, total_sims=total_sims)
+                t=t, get_sample=get_sample, total_sims=total_sims
+            )
         return False
 
     def configure_sampler(self, sampler) -> None:
@@ -165,6 +168,7 @@ class IdentitySumstat(Sumstat):
         self,
         trafos: List[Callable[[np.ndarray], np.ndarray]] = None,
         pre: Sumstat = None,
+        shape_out: Tuple[int, ...] = (-1,),
     ):
         """
         Parameters
@@ -175,12 +179,25 @@ class IdentitySumstat(Sumstat):
             Optional transformations to apply, should be vectorized.
             Note that if the original data should be contained, a
             transformation s.a. `lambda x: x` must be added.
+        shape_out:
+            Shape the (otherwise flat) output is converted to, via
+            :py:func:`numpy.reshape`.
+            Defaults to (-1,) and thus a flat array. Sometimes a row vector
+            (1, -1) may be preferable, e.g. to treat simulations as replicates.
+            For more complex shapes, tailored mappings may be preferable by
+            deriving from Sumstat or IdentitySumstat.
         """
         super().__init__(pre=pre)
-        self.trafos = trafos
+        self.trafos: List[Callable[[np.ndarray], np.ndarray]] = trafos
+        self.shape_out: Tuple[int, ...] = shape_out
 
     @io_dict2arr
     def __call__(self, data: Union[dict, np.ndarray]) -> np.ndarray:
+        """
+        Returns
+        -------
+        sumstat: Concatenated summary statistics array of shape (n,1) or (1,n).
+        """
         # apply previous statistics
         if self.pre is not None:
             data = self.pre(data)
@@ -189,7 +206,12 @@ class IdentitySumstat(Sumstat):
             # create one long array until structure ever becomes interesting
             # also allows trafos to yield differing dimensions
             data = np.concatenate(
-                [trafo(data).flatten() for trafo in self.trafos])
+                [trafo(data).flatten() for trafo in self.trafos]
+            )
+
+        # reshape
+        data = data.reshape(self.shape_out)
+
         return data
 
     def get_ids(self):
@@ -202,5 +224,7 @@ class IdentitySumstat(Sumstat):
         return super().get_ids()
 
     def __str__(self) -> str:
-        return f"<{self.__class__.__name__} pre={self.pre}, " \
-               f"trafos={self.trafos}>"
+        return (
+            f"<{self.__class__.__name__} pre={self.pre}, "
+            f"trafos={self.trafos}>"
+        )
